@@ -7,7 +7,9 @@
  * in the file LICENSE in the source distribution or at
  * https://www.openssl.org/source/license.html
  */
+/* clang-format off */
 
+/* clang-format on */
 
 /*
  * Refer to https://csrc.nist.gov/publications/detail/sp/800-56c/rev-1/final
@@ -56,8 +58,8 @@
 
 typedef struct {
     void *provctx;
-    EVP_MAC_CTX *macctx;         /* H(x) = HMAC_hash OR H(x) = KMAC */
-    PROV_DIGEST digest;          /* H(x) = hash(x) */
+    EVP_MAC_CTX *macctx; /* H(x) = HMAC_hash OR H(x) = KMAC */
+    PROV_DIGEST digest; /* H(x) = hash(x) */
     unsigned char *secret;
     size_t secret_len;
     unsigned char *info;
@@ -69,7 +71,7 @@ typedef struct {
     OSSL_FIPS_IND_DECLARE
 } KDF_SSKDF;
 
-#define SSKDF_MAX_INLEN (1<<30)
+#define SSKDF_MAX_INLEN (1 << 30)
 #define SSKDF_KMAC128_DEFAULT_SALT_SIZE (168 - 4)
 #define SSKDF_KMAC256_DEFAULT_SALT_SIZE (136 - 4)
 
@@ -101,10 +103,10 @@ static OSSL_FUNC_kdf_set_ctx_params_fn x963kdf_set_ctx_params;
  *   result[i] = Hash(z || counter || info) for X9.63.
  */
 static int SSKDF_hash_kdm(const EVP_MD *kdf_md,
-                          const unsigned char *z, size_t z_len,
-                          const unsigned char *info, size_t info_len,
-                          unsigned int append_ctr,
-                          unsigned char *derived_key, size_t derived_key_len)
+    const unsigned char *z, size_t z_len,
+    const unsigned char *info, size_t info_len,
+    unsigned int append_ctr,
+    unsigned char *derived_key, size_t derived_key_len)
 {
     int ret = 0, hlen;
     size_t counter, out_len, len = derived_key_len;
@@ -114,8 +116,8 @@ static int SSKDF_hash_kdm(const EVP_MD *kdf_md,
     EVP_MD_CTX *ctx = NULL, *ctx_init = NULL;
 
     if (z_len > SSKDF_MAX_INLEN || info_len > SSKDF_MAX_INLEN
-            || derived_key_len > SSKDF_MAX_INLEN
-            || derived_key_len == 0)
+        || derived_key_len > SSKDF_MAX_INLEN
+        || derived_key_len == 0)
         return 0;
 
     hlen = EVP_MD_get_size(kdf_md);
@@ -166,8 +168,8 @@ end:
 }
 
 static int kmac_init(EVP_MAC_CTX *ctx, const unsigned char *custom,
-                     size_t custom_len, size_t kmac_out_len,
-                     size_t derived_key_len, unsigned char **out)
+    size_t custom_len, size_t kmac_out_len,
+    size_t derived_key_len, unsigned char **out)
 {
     OSSL_PARAM params[2];
 
@@ -176,7 +178,7 @@ static int kmac_init(EVP_MAC_CTX *ctx, const unsigned char *custom,
         return 1;
 
     params[0] = OSSL_PARAM_construct_octet_string(OSSL_MAC_PARAM_CUSTOM,
-                                                  (void *)custom, custom_len);
+        (void *)custom, custom_len);
     params[1] = OSSL_PARAM_construct_end();
 
     if (!EVP_MAC_CTX_set_params(ctx, params))
@@ -187,15 +189,15 @@ static int kmac_init(EVP_MAC_CTX *ctx, const unsigned char *custom,
         kmac_out_len = derived_key_len;
     /* otherwise check the size is valid */
     else if (!(kmac_out_len == derived_key_len
-            || kmac_out_len == 20
-            || kmac_out_len == 28
-            || kmac_out_len == 32
-            || kmac_out_len == 48
-            || kmac_out_len == 64))
+                 || kmac_out_len == 20
+                 || kmac_out_len == 28
+                 || kmac_out_len == 32
+                 || kmac_out_len == 48
+                 || kmac_out_len == 64))
         return 0;
 
     params[0] = OSSL_PARAM_construct_size_t(OSSL_MAC_PARAM_SIZE,
-                                            &kmac_out_len);
+        &kmac_out_len);
 
     if (EVP_MAC_CTX_set_params(ctx, params) <= 0)
         return 0;
@@ -219,12 +221,12 @@ static int kmac_init(EVP_MAC_CTX *ctx, const unsigned char *custom,
  *     H(x) = KMAC#(salt, x, outbits, CustomString='KDF')
  */
 static int SSKDF_mac_kdm(EVP_MAC_CTX *ctx_init,
-                         const unsigned char *kmac_custom,
-                         size_t kmac_custom_len, size_t kmac_out_len,
-                         const unsigned char *salt, size_t salt_len,
-                         const unsigned char *z, size_t z_len,
-                         const unsigned char *info, size_t info_len,
-                         unsigned char *derived_key, size_t derived_key_len)
+    const unsigned char *kmac_custom,
+    size_t kmac_custom_len, size_t kmac_out_len,
+    const unsigned char *salt, size_t salt_len,
+    const unsigned char *z, size_t z_len,
+    const unsigned char *info, size_t info_len,
+    unsigned char *derived_key, size_t derived_key_len)
 {
     int ret = 0;
     size_t counter, out_len, len;
@@ -235,12 +237,12 @@ static int SSKDF_mac_kdm(EVP_MAC_CTX *ctx_init,
     unsigned char *mac = mac_buf, *kmac_buffer = NULL;
 
     if (z_len > SSKDF_MAX_INLEN || info_len > SSKDF_MAX_INLEN
-            || derived_key_len > SSKDF_MAX_INLEN
-            || derived_key_len == 0)
+        || derived_key_len > SSKDF_MAX_INLEN
+        || derived_key_len == 0)
         return 0;
 
     if (!kmac_init(ctx_init, kmac_custom, kmac_custom_len, kmac_out_len,
-                   derived_key_len, &kmac_buffer))
+            derived_key_len, &kmac_buffer))
         goto end;
     if (kmac_buffer != NULL)
         mac = kmac_buffer;
@@ -343,12 +345,12 @@ static void *sskdf_dup(void *vctx)
                 goto err;
         }
         if (!ossl_prov_memdup(src->info, src->info_len,
-                              &dest->info, &dest->info_len)
-                || !ossl_prov_memdup(src->salt, src->salt_len,
-                                     &dest->salt , &dest->salt_len)
-                || !ossl_prov_memdup(src->secret, src->secret_len,
-                                     &dest->secret, &dest->secret_len)
-                || !ossl_prov_digest_copy(&dest->digest, &src->digest))
+                &dest->info, &dest->info_len)
+            || !ossl_prov_memdup(src->salt, src->salt_len,
+                &dest->salt, &dest->salt_len)
+            || !ossl_prov_memdup(src->secret, src->secret_len,
+                &dest->secret, &dest->secret_len)
+            || !ossl_prov_digest_copy(&dest->digest, &src->digest))
             goto err;
         dest->out_len = src->out_len;
         dest->is_kmac = src->is_kmac;
@@ -356,7 +358,7 @@ static void *sskdf_dup(void *vctx)
     }
     return dest;
 
- err:
+err:
     sskdf_free(dest);
     return NULL;
 }
@@ -386,8 +388,8 @@ static int fips_sskdf_key_check_passed(KDF_SSKDF *ctx)
 
     if (!key_approved) {
         if (!OSSL_FIPS_IND_ON_UNAPPROVED(ctx, OSSL_FIPS_IND_SETTABLE0,
-                                         libctx, "SSKDF", "Key size",
-                                         ossl_fips_config_sskdf_key_check)) {
+                libctx, "SSKDF", "Key size",
+                ossl_fips_config_sskdf_key_check)) {
             ERR_raise(ERR_LIB_PROV, PROV_R_INVALID_KEY_LENGTH);
             return 0;
         }
@@ -397,7 +399,7 @@ static int fips_sskdf_key_check_passed(KDF_SSKDF *ctx)
 #endif
 
 static int sskdf_derive(void *vctx, unsigned char *key, size_t keylen,
-                        const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     KDF_SSKDF *ctx = (KDF_SSKDF *)vctx;
     const EVP_MD *md;
@@ -448,10 +450,10 @@ static int sskdf_derive(void *vctx, unsigned char *key, size_t keylen,
             ctx->salt_len = default_salt_len;
         }
         ret = SSKDF_mac_kdm(ctx->macctx,
-                            custom, custom_len, ctx->out_len,
-                            ctx->salt, ctx->salt_len,
-                            ctx->secret, ctx->secret_len,
-                            ctx->info, ctx->info_len, key, keylen);
+            custom, custom_len, ctx->out_len,
+            ctx->salt, ctx->salt_len,
+            ctx->secret, ctx->secret_len,
+            ctx->info, ctx->info_len, key, keylen);
         return ret;
     } else {
         /* H(x) = hash */
@@ -460,7 +462,7 @@ static int sskdf_derive(void *vctx, unsigned char *key, size_t keylen,
             return 0;
         }
         return SSKDF_hash_kdm(md, ctx->secret, ctx->secret_len,
-                              ctx->info, ctx->info_len, 0, key, keylen);
+            ctx->info, ctx->info_len, 0, key, keylen);
     }
 }
 
@@ -479,8 +481,8 @@ static int fips_x963kdf_digest_check_passed(KDF_SSKDF *ctx, const EVP_MD *md)
 
     if (digest_unapproved) {
         if (!OSSL_FIPS_IND_ON_UNAPPROVED(ctx, OSSL_FIPS_IND_SETTABLE0,
-                                         libctx, "X963KDF", "Digest",
-                                         ossl_fips_config_x963kdf_digest_check)) {
+                libctx, "X963KDF", "Digest",
+                ossl_fips_config_x963kdf_digest_check)) {
             ERR_raise(ERR_LIB_PROV, PROV_R_DIGEST_NOT_ALLOWED);
             return 0;
         }
@@ -495,8 +497,8 @@ static int fips_x963kdf_key_check_passed(KDF_SSKDF *ctx)
 
     if (!key_approved) {
         if (!OSSL_FIPS_IND_ON_UNAPPROVED(ctx, OSSL_FIPS_IND_SETTABLE1,
-                                         libctx, "X963KDF", "Key size",
-                                         ossl_fips_config_x963kdf_key_check)) {
+                libctx, "X963KDF", "Key size",
+                ossl_fips_config_x963kdf_key_check)) {
             ERR_raise(ERR_LIB_PROV, PROV_R_INVALID_KEY_LENGTH);
             return 0;
         }
@@ -506,7 +508,7 @@ static int fips_x963kdf_key_check_passed(KDF_SSKDF *ctx)
 #endif
 
 static int x963kdf_derive(void *vctx, unsigned char *key, size_t keylen,
-                          const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     KDF_SSKDF *ctx = (KDF_SSKDF *)vctx;
     const EVP_MD *md;
@@ -532,7 +534,7 @@ static int x963kdf_derive(void *vctx, unsigned char *key, size_t keylen,
     }
 
     return SSKDF_hash_kdm(md, ctx->secret, ctx->secret_len,
-                          ctx->info, ctx->info_len, 1, key, keylen);
+        ctx->info, ctx->info_len, 1, key, keylen);
 }
 
 struct sskdf_all_set_ctx_params_st {
@@ -551,9 +553,8 @@ struct sskdf_all_set_ctx_params_st {
     int num_info;
 };
 
-static int sskdf_common_set_ctx_params
-        (KDF_SSKDF *ctx, struct sskdf_all_set_ctx_params_st *p,
-         const OSSL_PARAM *params)
+static int sskdf_common_set_ctx_params(KDF_SSKDF *ctx, struct sskdf_all_set_ctx_params_st *p,
+    const OSSL_PARAM *params)
 {
     OSSL_LIB_CTX *libctx = PROV_LIBCTX_OF(ctx->provctx);
     const EVP_MD *md = NULL;
@@ -561,21 +562,21 @@ static int sskdf_common_set_ctx_params
     int r;
 
     if (!ossl_prov_macctx_load(&ctx->macctx,
-                               p->mac, NULL, p->digest, p->propq, p->engine,
-                               NULL, NULL, NULL, libctx))
+            p->mac, NULL, p->digest, p->propq, p->engine,
+            NULL, NULL, NULL, libctx))
         return 0;
     if (ctx->macctx != NULL) {
-         if (EVP_MAC_is_a(EVP_MAC_CTX_get0_mac(ctx->macctx),
-                          OSSL_MAC_NAME_KMAC128)
-             || EVP_MAC_is_a(EVP_MAC_CTX_get0_mac(ctx->macctx),
-                             OSSL_MAC_NAME_KMAC256)) {
-             ctx->is_kmac = 1;
-         }
+        if (EVP_MAC_is_a(EVP_MAC_CTX_get0_mac(ctx->macctx),
+                OSSL_MAC_NAME_KMAC128)
+            || EVP_MAC_is_a(EVP_MAC_CTX_get0_mac(ctx->macctx),
+                OSSL_MAC_NAME_KMAC256)) {
+            ctx->is_kmac = 1;
+        }
     }
 
     if (p->digest != NULL) {
         if (!ossl_prov_digest_load(&ctx->digest, p->digest,
-                                   p->propq, p->engine, libctx))
+                p->propq, p->engine, libctx))
             return 0;
 
         md = ossl_prov_digest_md(&ctx->digest);
@@ -586,16 +587,18 @@ static int sskdf_common_set_ctx_params
     }
 
     r = ossl_param_get1_octet_string_from_param(p->secret, &ctx->secret,
-                                                &ctx->secret_len);
+        &ctx->secret_len);
     if (r == 0)
         return 0;
 
     if (ossl_param_get1_concat_octet_string(p->num_info, p->info, &ctx->info,
-                                            &ctx->info_len) == 0)
+            &ctx->info_len)
+        == 0)
         return 0;
 
     if (ossl_param_get1_octet_string_from_param(p->salt, &ctx->salt,
-                                                &ctx->salt_len) == 0)
+            &ctx->salt_len)
+        == 0)
         return 0;
 
     if (p->size != NULL) {
@@ -608,6 +611,7 @@ static int sskdf_common_set_ctx_params
 
 #define sskdf_set_ctx_params_st sskdf_all_set_ctx_params_st
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef sskdf_set_ctx_params_list
 static const OSSL_PARAM sskdf_set_ctx_params_list[] = {
@@ -800,6 +804,7 @@ static int sskdf_set_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int sskdf_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 {
@@ -825,11 +830,12 @@ static int sskdf_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *sskdf_settable_ctx_params(ossl_unused void *ctx,
-                                                   ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     return sskdf_set_ctx_params_list;
 }
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef sskdf_get_ctx_params_list
 static const OSSL_PARAM sskdf_get_ctx_params_list[] = {
@@ -890,6 +896,7 @@ static int sskdf_get_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int sskdf_common_get_ctx_params(void *vctx, OSSL_PARAM params[])
 {
@@ -910,14 +917,14 @@ static int sskdf_common_get_ctx_params(void *vctx, OSSL_PARAM params[])
     return 1;
 }
 
-static const OSSL_PARAM *sskdf_common_gettable_ctx_params
-        (ossl_unused void *ctx, ossl_unused void *provctx)
+static const OSSL_PARAM *sskdf_common_gettable_ctx_params(ossl_unused void *ctx, ossl_unused void *provctx)
 {
     return sskdf_get_ctx_params_list;
 }
 
 #define x963kdf_set_ctx_params_st sskdf_all_set_ctx_params_st
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef x963kdf_set_ctx_params_list
 static const OSSL_PARAM x963kdf_set_ctx_params_list[] = {
@@ -1156,6 +1163,7 @@ static int x963kdf_set_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int x963kdf_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 {
@@ -1190,37 +1198,37 @@ static int x963kdf_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *x963kdf_settable_ctx_params(ossl_unused void *ctx,
-                                                     ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     return x963kdf_set_ctx_params_list;
 }
 
 const OSSL_DISPATCH ossl_kdf_sskdf_functions[] = {
-    { OSSL_FUNC_KDF_NEWCTX, (void(*)(void))sskdf_new },
-    { OSSL_FUNC_KDF_DUPCTX, (void(*)(void))sskdf_dup },
-    { OSSL_FUNC_KDF_FREECTX, (void(*)(void))sskdf_free },
-    { OSSL_FUNC_KDF_RESET, (void(*)(void))sskdf_reset },
-    { OSSL_FUNC_KDF_DERIVE, (void(*)(void))sskdf_derive },
+    { OSSL_FUNC_KDF_NEWCTX, (void (*)(void))sskdf_new },
+    { OSSL_FUNC_KDF_DUPCTX, (void (*)(void))sskdf_dup },
+    { OSSL_FUNC_KDF_FREECTX, (void (*)(void))sskdf_free },
+    { OSSL_FUNC_KDF_RESET, (void (*)(void))sskdf_reset },
+    { OSSL_FUNC_KDF_DERIVE, (void (*)(void))sskdf_derive },
     { OSSL_FUNC_KDF_SETTABLE_CTX_PARAMS,
-      (void(*)(void))sskdf_settable_ctx_params },
-    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void(*)(void))sskdf_set_ctx_params },
+        (void (*)(void))sskdf_settable_ctx_params },
+    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void (*)(void))sskdf_set_ctx_params },
     { OSSL_FUNC_KDF_GETTABLE_CTX_PARAMS,
-      (void(*)(void))sskdf_common_gettable_ctx_params },
-    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void(*)(void))sskdf_common_get_ctx_params },
+        (void (*)(void))sskdf_common_gettable_ctx_params },
+    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void (*)(void))sskdf_common_get_ctx_params },
     OSSL_DISPATCH_END
 };
 
 const OSSL_DISPATCH ossl_kdf_x963_kdf_functions[] = {
-    { OSSL_FUNC_KDF_NEWCTX, (void(*)(void))sskdf_new },
-    { OSSL_FUNC_KDF_DUPCTX, (void(*)(void))sskdf_dup },
-    { OSSL_FUNC_KDF_FREECTX, (void(*)(void))sskdf_free },
-    { OSSL_FUNC_KDF_RESET, (void(*)(void))sskdf_reset },
-    { OSSL_FUNC_KDF_DERIVE, (void(*)(void))x963kdf_derive },
+    { OSSL_FUNC_KDF_NEWCTX, (void (*)(void))sskdf_new },
+    { OSSL_FUNC_KDF_DUPCTX, (void (*)(void))sskdf_dup },
+    { OSSL_FUNC_KDF_FREECTX, (void (*)(void))sskdf_free },
+    { OSSL_FUNC_KDF_RESET, (void (*)(void))sskdf_reset },
+    { OSSL_FUNC_KDF_DERIVE, (void (*)(void))x963kdf_derive },
     { OSSL_FUNC_KDF_SETTABLE_CTX_PARAMS,
-      (void(*)(void))x963kdf_settable_ctx_params },
-    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void(*)(void))x963kdf_set_ctx_params },
+        (void (*)(void))x963kdf_settable_ctx_params },
+    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void (*)(void))x963kdf_set_ctx_params },
     { OSSL_FUNC_KDF_GETTABLE_CTX_PARAMS,
-      (void(*)(void))sskdf_common_gettable_ctx_params },
-    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void(*)(void))sskdf_common_get_ctx_params },
+        (void (*)(void))sskdf_common_gettable_ctx_params },
+    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void (*)(void))sskdf_common_get_ctx_params },
     OSSL_DISPATCH_END
 };
