@@ -6,7 +6,9 @@
  * in the file LICENSE in the source distribution or at
  * https://www.openssl.org/source/license.html
  */
+/* clang-format off */
 
+/* clang-format on */
 
 #include <stdlib.h>
 #include <string.h>
@@ -39,9 +41,9 @@ static OSSL_FUNC_rand_get_ctx_params_fn drbg_ctr_get_ctx_params;
 static OSSL_FUNC_rand_verify_zeroization_fn drbg_ctr_verify_zeroization;
 
 static int drbg_ctr_set_ctx_params_locked(PROV_DRBG *drbg,
-                                          const struct drbg_set_ctx_params_st *p);
+    const struct drbg_set_ctx_params_st *p);
 static int drbg_ctr_set_ctx_params_decoder(const OSSL_PARAM params[],
-                                           struct drbg_set_ctx_params_st *p);
+    struct drbg_set_ctx_params_st *p);
 
 /*
  * The state of a DRBG AES-CTR.
@@ -110,7 +112,7 @@ static void ctr_XOR(PROV_DRBG_CTR *ctr, const unsigned char *in, size_t inlen)
  * Process a complete block using BCC algorithm of SP 800-90A 10.3.3
  */
 __owur static int ctr_BCC_block(PROV_DRBG_CTR *ctr, unsigned char *out,
-                                const unsigned char *in, int len)
+    const unsigned char *in, int len)
 {
     int i, outlen = AES_BLOCK_SIZE;
 
@@ -123,7 +125,6 @@ __owur static int ctr_BCC_block(PROV_DRBG_CTR *ctr, unsigned char *out,
     return 1;
 }
 
-
 /*
  * Handle several BCC operations for as much data as we need for K and X
  */
@@ -147,7 +148,7 @@ __owur static int ctr_BCC_blocks(PROV_DRBG_CTR *ctr, const unsigned char *in)
  */
 __owur static int ctr_BCC_init(PROV_DRBG_CTR *ctr)
 {
-    unsigned char bltmp[48] = {0};
+    unsigned char bltmp[48] = { 0 };
     unsigned char num_of_blk;
 
     memset(ctr->KX, 0, 48);
@@ -161,7 +162,7 @@ __owur static int ctr_BCC_init(PROV_DRBG_CTR *ctr)
  * Process several blocks into BCC algorithm, some possibly partial
  */
 __owur static int ctr_BCC_update(PROV_DRBG_CTR *ctr,
-                                 const unsigned char *in, size_t inlen)
+    const unsigned char *in, size_t inlen)
 {
     if (in == NULL || inlen == 0)
         return 1;
@@ -206,9 +207,9 @@ __owur static int ctr_BCC_final(PROV_DRBG_CTR *ctr)
 }
 
 __owur static int ctr_df(PROV_DRBG_CTR *ctr,
-                         const unsigned char *in1, size_t in1len,
-                         const unsigned char *in2, size_t in2len,
-                         const unsigned char *in3, size_t in3len)
+    const unsigned char *in1, size_t in1len,
+    const unsigned char *in2, size_t in2len,
+    const unsigned char *in3, size_t in3len)
 {
     static unsigned char c80 = 0x80;
     size_t inlen;
@@ -247,16 +248,16 @@ __owur static int ctr_df(PROV_DRBG_CTR *ctr,
         return 0;
     /* X follows key K */
     if (!EVP_CipherUpdate(ctr->ctx_ecb, ctr->KX, &outlen, ctr->KX + ctr->keylen,
-                          AES_BLOCK_SIZE)
+            AES_BLOCK_SIZE)
         || outlen != AES_BLOCK_SIZE)
         return 0;
     if (!EVP_CipherUpdate(ctr->ctx_ecb, ctr->KX + 16, &outlen, ctr->KX,
-                          AES_BLOCK_SIZE)
+            AES_BLOCK_SIZE)
         || outlen != AES_BLOCK_SIZE)
         return 0;
     if (ctr->keylen != 16)
         if (!EVP_CipherUpdate(ctr->ctx_ecb, ctr->KX + 32, &outlen,
-                              ctr->KX + 16, AES_BLOCK_SIZE)
+                ctr->KX + 16, AES_BLOCK_SIZE)
             || outlen != AES_BLOCK_SIZE)
             return 0;
     return 1;
@@ -269,9 +270,9 @@ __owur static int ctr_df(PROV_DRBG_CTR *ctr,
  * so we handle both cases in this function instead.
  */
 __owur static int ctr_update(PROV_DRBG *drbg,
-                             const unsigned char *in1, size_t in1len,
-                             const unsigned char *in2, size_t in2len,
-                             const unsigned char *nonce, size_t noncelen)
+    const unsigned char *in1, size_t in1len,
+    const unsigned char *in2, size_t in2len,
+    const unsigned char *nonce, size_t noncelen)
 {
     PROV_DRBG_CTR *ctr = (PROV_DRBG_CTR *)drbg->data;
     int outlen = AES_BLOCK_SIZE;
@@ -290,7 +291,7 @@ __owur static int ctr_update(PROV_DRBG *drbg,
         len = 48;
     }
     if (!EVP_CipherUpdate(ctr->ctx_ecb, out, &outlen, V_tmp, len)
-            || outlen != len)
+        || outlen != len)
         return 0;
     memcpy(ctr->K, out, ctr->keylen);
     memcpy(ctr->V, out + ctr->keylen, 16);
@@ -315,9 +316,9 @@ __owur static int ctr_update(PROV_DRBG *drbg,
 }
 
 static int drbg_ctr_instantiate(PROV_DRBG *drbg,
-                                const unsigned char *entropy, size_t entropylen,
-                                const unsigned char *nonce, size_t noncelen,
-                                const unsigned char *pers, size_t perslen)
+    const unsigned char *entropy, size_t entropylen,
+    const unsigned char *nonce, size_t noncelen,
+    const unsigned char *pers, size_t perslen)
 {
     PROV_DRBG_CTR *ctr = (PROV_DRBG_CTR *)drbg->data;
 
@@ -336,10 +337,10 @@ static int drbg_ctr_instantiate(PROV_DRBG *drbg,
 }
 
 static int drbg_ctr_instantiate_wrapper(void *vdrbg, unsigned int strength,
-                                        int prediction_resistance,
-                                        const unsigned char *pstr,
-                                        size_t pstr_len,
-                                        const OSSL_PARAM params[])
+    int prediction_resistance,
+    const unsigned char *pstr,
+    size_t pstr_len,
+    const OSSL_PARAM params[])
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
     struct drbg_set_ctx_params_st p;
@@ -352,19 +353,19 @@ static int drbg_ctr_instantiate_wrapper(void *vdrbg, unsigned int strength,
         return 0;
 
     if (!ossl_prov_is_running()
-            || !drbg_ctr_set_ctx_params_locked(drbg, &p))
+        || !drbg_ctr_set_ctx_params_locked(drbg, &p))
         goto err;
     ret = ossl_prov_drbg_instantiate(drbg, strength, prediction_resistance,
-                                     pstr, pstr_len);
- err:
+        pstr, pstr_len);
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
     return ret;
 }
 
 static int drbg_ctr_reseed(PROV_DRBG *drbg,
-                           const unsigned char *entropy, size_t entropylen,
-                           const unsigned char *adin, size_t adinlen)
+    const unsigned char *entropy, size_t entropylen,
+    const unsigned char *adin, size_t adinlen)
 {
     PROV_DRBG_CTR *ctr = (PROV_DRBG_CTR *)drbg->data;
 
@@ -378,13 +379,13 @@ static int drbg_ctr_reseed(PROV_DRBG *drbg,
 }
 
 static int drbg_ctr_reseed_wrapper(void *vdrbg, int prediction_resistance,
-                                   const unsigned char *ent, size_t ent_len,
-                                   const unsigned char *adin, size_t adin_len)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
 
     return ossl_prov_drbg_reseed(drbg, prediction_resistance, ent, ent_len,
-                                 adin, adin_len);
+        adin, adin_len);
 }
 
 static void ctr96_inc(unsigned char *counter)
@@ -400,8 +401,8 @@ static void ctr96_inc(unsigned char *counter)
 }
 
 static int drbg_ctr_generate(PROV_DRBG *drbg,
-                             unsigned char *out, size_t outlen,
-                             const unsigned char *adin, size_t adinlen)
+    unsigned char *out, size_t outlen,
+    const unsigned char *adin, size_t adinlen)
 {
     PROV_DRBG_CTR *ctr = (PROV_DRBG_CTR *)drbg->data;
     unsigned int ctr32, blocks;
@@ -435,7 +436,7 @@ static int drbg_ctr_generate(PROV_DRBG *drbg,
 
     do {
         if (!EVP_CipherInit_ex(ctr->ctx_ctr,
-                               NULL, NULL, NULL, ctr->V, -1))
+                NULL, NULL, NULL, ctr->V, -1))
             return 0;
 
         /*-
@@ -473,15 +474,14 @@ static int drbg_ctr_generate(PROV_DRBG *drbg,
     return 1;
 }
 
-static int drbg_ctr_generate_wrapper
-    (void *vdrbg, unsigned char *out, size_t outlen,
-     unsigned int strength, int prediction_resistance,
-     const unsigned char *adin, size_t adin_len)
+static int drbg_ctr_generate_wrapper(void *vdrbg, unsigned char *out, size_t outlen,
+    unsigned int strength, int prediction_resistance,
+    const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
 
     return ossl_prov_drbg_generate(drbg, out, outlen, strength,
-                                   prediction_resistance, adin, adin_len);
+        prediction_resistance, adin, adin_len);
 }
 
 static int drbg_ctr_uninstantiate(PROV_DRBG *drbg)
@@ -529,7 +529,7 @@ static int drbg_ctr_verify_zeroization(void *vdrbg)
         goto err;
 
     ret = 1;
- err:
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
     return ret;
@@ -588,9 +588,9 @@ static int drbg_ctr_init(PROV_DRBG *drbg)
     }
 
     if (!EVP_CipherInit_ex(ctr->ctx_ecb,
-                           ctr->cipher_ecb, NULL, NULL, NULL, 1)
+            ctr->cipher_ecb, NULL, NULL, NULL, 1)
         || !EVP_CipherInit_ex(ctr->ctx_ctr,
-                              ctr->cipher_ctr, NULL, NULL, NULL, 1)) {
+            ctr->cipher_ctr, NULL, NULL, NULL, 1)) {
         ERR_raise(ERR_LIB_PROV, PROV_R_UNABLE_TO_INITIALISE_CIPHERS);
         goto err;
     }
@@ -615,7 +615,7 @@ static int drbg_ctr_init(PROV_DRBG *drbg)
         }
         /* Set key schedule for df_key */
         if (!EVP_CipherInit_ex(ctr->ctx_df,
-                               ctr->cipher_ecb, NULL, df_key, NULL, 1)) {
+                ctr->cipher_ecb, NULL, df_key, NULL, 1)) {
             ERR_raise(ERR_LIB_PROV, PROV_R_DERIVATION_FUNCTION_INIT_FAILED);
             goto err;
         }
@@ -644,12 +644,12 @@ static int drbg_ctr_new(PROV_DRBG *drbg)
 }
 
 static void *drbg_ctr_new_wrapper(void *provctx, void *parent,
-                                   const OSSL_DISPATCH *parent_dispatch)
+    const OSSL_DISPATCH *parent_dispatch)
 {
     return ossl_rand_drbg_new(provctx, parent, parent_dispatch,
-                              &drbg_ctr_new, &drbg_ctr_free,
-                              &drbg_ctr_instantiate, &drbg_ctr_uninstantiate,
-                              &drbg_ctr_reseed, &drbg_ctr_generate);
+        &drbg_ctr_new, &drbg_ctr_free,
+        &drbg_ctr_instantiate, &drbg_ctr_uninstantiate,
+        &drbg_ctr_reseed, &drbg_ctr_generate);
 }
 
 static void drbg_ctr_free(void *vdrbg)
@@ -669,8 +669,9 @@ static void drbg_ctr_free(void *vdrbg)
     ossl_rand_drbg_free(drbg);
 }
 
-#define drbg_ctr_get_ctx_params_st  drbg_get_ctx_params_st
+#define drbg_ctr_get_ctx_params_st drbg_get_ctx_params_st
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef drbg_ctr_get_ctx_params_list
 static const OSSL_PARAM drbg_ctr_get_ctx_params_list[] = {
@@ -1010,6 +1011,7 @@ static int drbg_ctr_get_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int drbg_ctr_get_ctx_params(void *vdrbg, OSSL_PARAM params[])
 {
@@ -1038,12 +1040,12 @@ static int drbg_ctr_get_ctx_params(void *vdrbg, OSSL_PARAM params[])
     if (p.cipher != NULL) {
         if (ctr->cipher_ctr == NULL
             || !OSSL_PARAM_set_utf8_string(p.cipher,
-                                           EVP_CIPHER_get0_name(ctr->cipher_ctr)))
+                EVP_CIPHER_get0_name(ctr->cipher_ctr)))
             goto err;
     }
 
     ret = ossl_drbg_get_ctx_params(drbg, &p);
- err:
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
 
@@ -1051,13 +1053,13 @@ static int drbg_ctr_get_ctx_params(void *vdrbg, OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *drbg_ctr_gettable_ctx_params(ossl_unused void *vctx,
-                                                      ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     return drbg_ctr_get_ctx_params_list;
 }
 
 static int drbg_ctr_set_ctx_params_locked(PROV_DRBG *ctx,
-                                          const struct drbg_set_ctx_params_st *p)
+    const struct drbg_set_ctx_params_st *p)
 {
     PROV_DRBG_CTR *ctr = (PROV_DRBG_CTR *)ctx->data;
     OSSL_LIB_CTX *libctx = PROV_LIBCTX_OF(ctx->provctx);
@@ -1082,7 +1084,8 @@ static int drbg_ctr_set_ctx_params_locked(PROV_DRBG *ctx,
         if (p->prov->data_type != OSSL_PARAM_UTF8_STRING)
             return 0;
         if ((prov = ossl_provider_find(libctx,
-                                       (const char *)p->prov->data, 1)) == NULL)
+                 (const char *)p->prov->data, 1))
+            == NULL)
             return 0;
     }
 
@@ -1092,7 +1095,7 @@ static int drbg_ctr_set_ctx_params_locked(PROV_DRBG *ctx,
         size_t ecb_str_len = sizeof("ECB") - 1;
 
         if (p->cipher->data_type != OSSL_PARAM_UTF8_STRING
-                || p->cipher->data_size < ctr_str_len) {
+            || p->cipher->data_size < ctr_str_len) {
             ossl_provider_free(prov);
             return 0;
         }
@@ -1144,8 +1147,9 @@ static int drbg_ctr_set_ctx_params_locked(PROV_DRBG *ctx,
     return ossl_drbg_set_ctx_params(ctx, p);
 }
 
-#define drbg_ctr_set_ctx_params_st  drbg_set_ctx_params_st
+#define drbg_ctr_set_ctx_params_st drbg_set_ctx_params_st
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef drbg_ctr_set_ctx_params_list
 static const OSSL_PARAM drbg_ctr_set_ctx_params_list[] = {
@@ -1302,6 +1306,7 @@ static int drbg_ctr_set_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int drbg_ctr_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 {
@@ -1324,32 +1329,32 @@ static int drbg_ctr_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *drbg_ctr_settable_ctx_params(ossl_unused void *vctx,
-                                                      ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     return drbg_ctr_set_ctx_params_list;
 }
 
 const OSSL_DISPATCH ossl_drbg_ctr_functions[] = {
-    { OSSL_FUNC_RAND_NEWCTX, (void(*)(void))drbg_ctr_new_wrapper },
-    { OSSL_FUNC_RAND_FREECTX, (void(*)(void))drbg_ctr_free },
+    { OSSL_FUNC_RAND_NEWCTX, (void (*)(void))drbg_ctr_new_wrapper },
+    { OSSL_FUNC_RAND_FREECTX, (void (*)(void))drbg_ctr_free },
     { OSSL_FUNC_RAND_INSTANTIATE,
-      (void(*)(void))drbg_ctr_instantiate_wrapper },
+        (void (*)(void))drbg_ctr_instantiate_wrapper },
     { OSSL_FUNC_RAND_UNINSTANTIATE,
-      (void(*)(void))drbg_ctr_uninstantiate_wrapper },
-    { OSSL_FUNC_RAND_GENERATE, (void(*)(void))drbg_ctr_generate_wrapper },
-    { OSSL_FUNC_RAND_RESEED, (void(*)(void))drbg_ctr_reseed_wrapper },
-    { OSSL_FUNC_RAND_ENABLE_LOCKING, (void(*)(void))ossl_drbg_enable_locking },
-    { OSSL_FUNC_RAND_LOCK, (void(*)(void))ossl_drbg_lock },
-    { OSSL_FUNC_RAND_UNLOCK, (void(*)(void))ossl_drbg_unlock },
+        (void (*)(void))drbg_ctr_uninstantiate_wrapper },
+    { OSSL_FUNC_RAND_GENERATE, (void (*)(void))drbg_ctr_generate_wrapper },
+    { OSSL_FUNC_RAND_RESEED, (void (*)(void))drbg_ctr_reseed_wrapper },
+    { OSSL_FUNC_RAND_ENABLE_LOCKING, (void (*)(void))ossl_drbg_enable_locking },
+    { OSSL_FUNC_RAND_LOCK, (void (*)(void))ossl_drbg_lock },
+    { OSSL_FUNC_RAND_UNLOCK, (void (*)(void))ossl_drbg_unlock },
     { OSSL_FUNC_RAND_SETTABLE_CTX_PARAMS,
-      (void(*)(void))drbg_ctr_settable_ctx_params },
-    { OSSL_FUNC_RAND_SET_CTX_PARAMS, (void(*)(void))drbg_ctr_set_ctx_params },
+        (void (*)(void))drbg_ctr_settable_ctx_params },
+    { OSSL_FUNC_RAND_SET_CTX_PARAMS, (void (*)(void))drbg_ctr_set_ctx_params },
     { OSSL_FUNC_RAND_GETTABLE_CTX_PARAMS,
-      (void(*)(void))drbg_ctr_gettable_ctx_params },
-    { OSSL_FUNC_RAND_GET_CTX_PARAMS, (void(*)(void))drbg_ctr_get_ctx_params },
+        (void (*)(void))drbg_ctr_gettable_ctx_params },
+    { OSSL_FUNC_RAND_GET_CTX_PARAMS, (void (*)(void))drbg_ctr_get_ctx_params },
     { OSSL_FUNC_RAND_VERIFY_ZEROIZATION,
-      (void(*)(void))drbg_ctr_verify_zeroization },
-    { OSSL_FUNC_RAND_GET_SEED, (void(*)(void))ossl_drbg_get_seed },
-    { OSSL_FUNC_RAND_CLEAR_SEED, (void(*)(void))ossl_drbg_clear_seed },
+        (void (*)(void))drbg_ctr_verify_zeroization },
+    { OSSL_FUNC_RAND_GET_SEED, (void (*)(void))ossl_drbg_get_seed },
+    { OSSL_FUNC_RAND_CLEAR_SEED, (void (*)(void))ossl_drbg_clear_seed },
     OSSL_DISPATCH_END
 };
