@@ -1,12 +1,14 @@
 /*
- * Copyright 2011-2025 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2011-2026 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
  * in the file LICENSE in the source distribution or at
  * https://www.openssl.org/source/license.html
  */
+/* clang-format off */
 
+/* clang-format on */
 
 #include <stdlib.h>
 #include <string.h>
@@ -37,10 +39,9 @@ static OSSL_FUNC_rand_gettable_ctx_params_fn drbg_hmac_gettable_ctx_params;
 static OSSL_FUNC_rand_get_ctx_params_fn drbg_hmac_get_ctx_params;
 static OSSL_FUNC_rand_verify_zeroization_fn drbg_hmac_verify_zeroization;
 
-static int drbg_hmac_set_ctx_params_locked
-        (PROV_DRBG *drbg, const struct drbg_set_ctx_params_st *p);
+static int drbg_hmac_set_ctx_params_locked(PROV_DRBG *drbg, const struct drbg_set_ctx_params_st *p);
 static int drbg_hmac_set_ctx_params_decoder(const OSSL_PARAM params[],
-                                            struct drbg_set_ctx_params_st *p);
+    struct drbg_set_ctx_params_st *p);
 
 /*
  * Called twice by SP800-90Ar1 10.1.2.2 HMAC_DRBG_Update_Process.
@@ -57,26 +58,26 @@ static int drbg_hmac_set_ctx_params_decoder(const OSSL_PARAM params[],
  * Returns zero if an error occurs otherwise it returns 1.
  */
 static int do_hmac(PROV_DRBG_HMAC *hmac, unsigned char inbyte,
-                   const unsigned char *in1, size_t in1len,
-                   const unsigned char *in2, size_t in2len,
-                   const unsigned char *in3, size_t in3len)
+    const unsigned char *in1, size_t in1len,
+    const unsigned char *in2, size_t in2len,
+    const unsigned char *in3, size_t in3len)
 {
     EVP_MAC_CTX *ctx = hmac->ctx;
 
     if (!EVP_MAC_init(ctx, hmac->K, hmac->blocklen, NULL)
-            /* K = HMAC(K, V || inbyte || [in1] || [in2] || [in3]) */
-            || !EVP_MAC_update(ctx, hmac->V, hmac->blocklen)
-            || !EVP_MAC_update(ctx, &inbyte, 1)
-            || !(in1 == NULL || in1len == 0 || EVP_MAC_update(ctx, in1, in1len))
-            || !(in2 == NULL || in2len == 0 || EVP_MAC_update(ctx, in2, in2len))
-            || !(in3 == NULL || in3len == 0 || EVP_MAC_update(ctx, in3, in3len))
-            || !EVP_MAC_final(ctx, hmac->K, NULL, sizeof(hmac->K)))
+        /* K = HMAC(K, V || inbyte || [in1] || [in2] || [in3]) */
+        || !EVP_MAC_update(ctx, hmac->V, hmac->blocklen)
+        || !EVP_MAC_update(ctx, &inbyte, 1)
+        || !(in1 == NULL || in1len == 0 || EVP_MAC_update(ctx, in1, in1len))
+        || !(in2 == NULL || in2len == 0 || EVP_MAC_update(ctx, in2, in2len))
+        || !(in3 == NULL || in3len == 0 || EVP_MAC_update(ctx, in3, in3len))
+        || !EVP_MAC_final(ctx, hmac->K, NULL, sizeof(hmac->K)))
         return 0;
 
-   /* V = HMAC(K, V) */
+    /* V = HMAC(K, V) */
     return EVP_MAC_init(ctx, hmac->K, hmac->blocklen, NULL)
-           && EVP_MAC_update(ctx, hmac->V, hmac->blocklen)
-           && EVP_MAC_final(ctx, hmac->V, NULL, sizeof(hmac->V));
+        && EVP_MAC_update(ctx, hmac->V, hmac->blocklen)
+        && EVP_MAC_final(ctx, hmac->V, NULL, sizeof(hmac->V));
 }
 
 /*
@@ -94,9 +95,9 @@ static int do_hmac(PROV_DRBG_HMAC *hmac, unsigned char inbyte,
  * Returns zero if an error occurs otherwise it returns 1.
  */
 static int drbg_hmac_update(PROV_DRBG_HMAC *hmac,
-                            const unsigned char *in1, size_t in1len,
-                            const unsigned char *in2, size_t in2len,
-                            const unsigned char *in3, size_t in3len)
+    const unsigned char *in1, size_t in1len,
+    const unsigned char *in2, size_t in2len,
+    const unsigned char *in3, size_t in3len)
 {
     /* (Steps 1-2) K = HMAC(K, V||0x00||provided_data). V = HMAC(K,V) */
     if (!do_hmac(hmac, 0x00, in1, in1len, in2, in2len, in3, in3len))
@@ -120,9 +121,9 @@ static int drbg_hmac_update(PROV_DRBG_HMAC *hmac,
  * Returns zero if an error occurs otherwise it returns 1.
  */
 int ossl_drbg_hmac_init(PROV_DRBG_HMAC *hmac,
-                        const unsigned char *ent, size_t ent_len,
-                        const unsigned char *nonce, size_t nonce_len,
-                        const unsigned char *pstr, size_t pstr_len)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *nonce, size_t nonce_len,
+    const unsigned char *pstr, size_t pstr_len)
 {
     if (hmac->ctx == NULL) {
         ERR_raise(ERR_LIB_PROV, PROV_R_MISSING_MAC);
@@ -135,22 +136,22 @@ int ossl_drbg_hmac_init(PROV_DRBG_HMAC *hmac,
     memset(hmac->V, 0x01, hmac->blocklen);
     /* (Step 4) (K,V) = HMAC_DRBG_Update(entropy||nonce||pers string, K, V) */
     return drbg_hmac_update(hmac, ent, ent_len, nonce, nonce_len, pstr,
-                            pstr_len);
+        pstr_len);
 }
 static int drbg_hmac_instantiate(PROV_DRBG *drbg,
-                                 const unsigned char *ent, size_t ent_len,
-                                 const unsigned char *nonce, size_t nonce_len,
-                                 const unsigned char *pstr, size_t pstr_len)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *nonce, size_t nonce_len,
+    const unsigned char *pstr, size_t pstr_len)
 {
     return ossl_drbg_hmac_init((PROV_DRBG_HMAC *)drbg->data, ent, ent_len,
-                               nonce, nonce_len, pstr, pstr_len);
+        nonce, nonce_len, pstr, pstr_len);
 }
 
 static int drbg_hmac_instantiate_wrapper(void *vdrbg, unsigned int strength,
-                                         int prediction_resistance,
-                                         const unsigned char *pstr,
-                                         size_t pstr_len,
-                                         const OSSL_PARAM params[])
+    int prediction_resistance,
+    const unsigned char *pstr,
+    size_t pstr_len,
+    const OSSL_PARAM params[])
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
     struct drbg_set_ctx_params_st p;
@@ -163,17 +164,16 @@ static int drbg_hmac_instantiate_wrapper(void *vdrbg, unsigned int strength,
         return 0;
 
     if (!ossl_prov_is_running()
-            || !drbg_hmac_set_ctx_params_locked(drbg, &p))
+        || !drbg_hmac_set_ctx_params_locked(drbg, &p))
         goto err;
     ret = ossl_prov_drbg_instantiate(drbg, strength, prediction_resistance,
-                                     pstr, pstr_len);
- err:
+        pstr, pstr_len);
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
     return ret;
 }
 
-
 /*
  * SP800-90Ar1 10.1.2.4 HMAC_DRBG_Reseed_Process:
  *
@@ -185,8 +185,8 @@ static int drbg_hmac_instantiate_wrapper(void *vdrbg, unsigned int strength,
  * Returns zero if an error occurs otherwise it returns 1.
  */
 static int drbg_hmac_reseed(PROV_DRBG *drbg,
-                            const unsigned char *ent, size_t ent_len,
-                            const unsigned char *adin, size_t adin_len)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG_HMAC *hmac = (PROV_DRBG_HMAC *)drbg->data;
 
@@ -195,13 +195,13 @@ static int drbg_hmac_reseed(PROV_DRBG *drbg,
 }
 
 static int drbg_hmac_reseed_wrapper(void *vdrbg, int prediction_resistance,
-                                    const unsigned char *ent, size_t ent_len,
-                                    const unsigned char *adin, size_t adin_len)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
 
     return ossl_prov_drbg_reseed(drbg, prediction_resistance, ent, ent_len,
-                                 adin, adin_len);
+        adin, adin_len);
 }
 
 /*
@@ -214,16 +214,16 @@ static int drbg_hmac_reseed_wrapper(void *vdrbg, int prediction_resistance,
  * Returns zero if an error occurs otherwise it returns 1.
  */
 int ossl_drbg_hmac_generate(PROV_DRBG_HMAC *hmac,
-                            unsigned char *out, size_t outlen,
-                            const unsigned char *adin, size_t adin_len)
+    unsigned char *out, size_t outlen,
+    const unsigned char *adin, size_t adin_len)
 {
     EVP_MAC_CTX *ctx = hmac->ctx;
     const unsigned char *temp = hmac->V;
 
     /* (Step 2) if adin != NULL then (K,V) = HMAC_DRBG_Update(adin, K, V) */
     if (adin != NULL
-            && adin_len > 0
-            && !drbg_hmac_update(hmac, adin, adin_len, NULL, 0, NULL, 0))
+        && adin_len > 0
+        && !drbg_hmac_update(hmac, adin, adin_len, NULL, 0, NULL, 0))
         return 0;
 
     /*
@@ -259,21 +259,21 @@ int ossl_drbg_hmac_generate(PROV_DRBG_HMAC *hmac,
 }
 
 static int drbg_hmac_generate(PROV_DRBG *drbg,
-                              unsigned char *out, size_t outlen,
-                              const unsigned char *adin, size_t adin_len)
+    unsigned char *out, size_t outlen,
+    const unsigned char *adin, size_t adin_len)
 {
     return ossl_drbg_hmac_generate((PROV_DRBG_HMAC *)drbg->data, out, outlen,
-                                    adin, adin_len);
+        adin, adin_len);
 }
 
 static int drbg_hmac_generate_wrapper(void *vdrbg,
-     unsigned char *out, size_t outlen, unsigned int strength,
-     int prediction_resistance, const unsigned char *adin, size_t adin_len)
+    unsigned char *out, size_t outlen, unsigned int strength,
+    int prediction_resistance, const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
 
     return ossl_prov_drbg_generate(drbg, out, outlen, strength,
-                                   prediction_resistance, adin, adin_len);
+        prediction_resistance, adin, adin_len);
 }
 
 static int drbg_hmac_uninstantiate(PROV_DRBG *drbg)
@@ -314,7 +314,7 @@ static int drbg_hmac_verify_zeroization(void *vdrbg)
     PROV_DRBG_VERIFY_ZEROIZATION(hmac->V);
 
     ret = 1;
- err:
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
     return ret;
@@ -343,12 +343,12 @@ static int drbg_hmac_new(PROV_DRBG *drbg)
 }
 
 static void *drbg_hmac_new_wrapper(void *provctx, void *parent,
-                                   const OSSL_DISPATCH *parent_dispatch)
+    const OSSL_DISPATCH *parent_dispatch)
 {
     return ossl_rand_drbg_new(provctx, parent, parent_dispatch,
-                              &drbg_hmac_new, &drbg_hmac_free,
-                              &drbg_hmac_instantiate, &drbg_hmac_uninstantiate,
-                              &drbg_hmac_reseed, &drbg_hmac_generate);
+        &drbg_hmac_new, &drbg_hmac_free,
+        &drbg_hmac_instantiate, &drbg_hmac_uninstantiate,
+        &drbg_hmac_reseed, &drbg_hmac_generate);
 }
 
 static void drbg_hmac_free(void *vdrbg)
@@ -364,8 +364,9 @@ static void drbg_hmac_free(void *vdrbg)
     ossl_rand_drbg_free(drbg);
 }
 
-#define drbg_hmac_get_ctx_params_st  drbg_get_ctx_params_st
+#define drbg_hmac_get_ctx_params_st drbg_get_ctx_params_st
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef drbg_hmac_get_ctx_params_list
 static const OSSL_PARAM drbg_hmac_get_ctx_params_list[] = {
@@ -707,6 +708,7 @@ static int drbg_hmac_get_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int drbg_hmac_get_ctx_params(void *vdrbg, OSSL_PARAM params[])
 {
@@ -742,12 +744,12 @@ static int drbg_hmac_get_ctx_params(void *vdrbg, OSSL_PARAM params[])
     if (p.digest != NULL) {
         md = ossl_prov_digest_md(&hmac->digest);
         if (md == NULL
-                || !OSSL_PARAM_set_utf8_string(p.digest, EVP_MD_get0_name(md)))
+            || !OSSL_PARAM_set_utf8_string(p.digest, EVP_MD_get0_name(md)))
             goto err;
     }
 
     ret = ossl_drbg_get_ctx_params(drbg, &p);
- err:
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
 
@@ -755,15 +757,15 @@ static int drbg_hmac_get_ctx_params(void *vdrbg, OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *drbg_hmac_gettable_ctx_params(ossl_unused void *vctx,
-                                                       ossl_unused void *p_ctx)
+    ossl_unused void *p_ctx)
 {
     return drbg_hmac_get_ctx_params_list;
 }
 
 static int drbg_fetch_algs_from_prov(const struct drbg_set_ctx_params_st *p,
-                                     OSSL_LIB_CTX *libctx,
-                                     EVP_MAC_CTX **macctx,
-                                     EVP_MD **digest)
+    OSSL_LIB_CTX *libctx,
+    EVP_MAC_CTX **macctx,
+    EVP_MD **digest)
 {
     OSSL_PROVIDER *prov = NULL;
     EVP_MD *md = NULL;
@@ -815,8 +817,7 @@ done:
     return ret;
 }
 
-static int drbg_hmac_set_ctx_params_locked
-        (PROV_DRBG *ctx, const struct drbg_set_ctx_params_st *p)
+static int drbg_hmac_set_ctx_params_locked(PROV_DRBG *ctx, const struct drbg_set_ctx_params_st *p)
 {
     PROV_DRBG_HMAC *hmac = (PROV_DRBG_HMAC *)ctx->data;
     OSSL_LIB_CTX *libctx = PROV_LIBCTX_OF(ctx->provctx);
@@ -833,22 +834,26 @@ static int drbg_hmac_set_ctx_params_locked
         (void)ERR_pop_to_mark();
         /* fall back to full implementation search */
         if (!ossl_prov_digest_load(&hmac->digest, p->digest, p->propq,
-                                   p->engine, libctx))
+                p->engine, libctx))
             return 0;
 
         if (!ossl_prov_macctx_load(&hmac->ctx, p->mac, NULL, p->digest,
-                                   p->propq, p->engine,
-                                   NULL, NULL, NULL, libctx))
+                p->propq, p->engine,
+                NULL, NULL, NULL, libctx))
             return 0;
     } else {
         (void)ERR_clear_last_mark();
         if (prov_md)
             ossl_prov_digest_set_md(&hmac->digest, prov_md);
+        if (!ossl_prov_macctx_load(&hmac->ctx, p->mac, NULL, p->digest,
+                p->propq, p->engine,
+                NULL, NULL, NULL, libctx))
+            return 0;
     }
 
     md = ossl_prov_digest_md(&hmac->digest);
     if (md != NULL && !ossl_drbg_verify_digest(ctx, libctx, md))
-        return 0;   /* Error already raised for us */
+        return 0; /* Error already raised for us */
 
     if (md != NULL && hmac->ctx != NULL) {
         /* These are taken from SP 800-90 10.1 Table 2 */
@@ -868,8 +873,9 @@ static int drbg_hmac_set_ctx_params_locked
     return ossl_drbg_set_ctx_params(ctx, p);
 }
 
-#define drbg_hmac_set_ctx_params_st  drbg_set_ctx_params_st
+#define drbg_hmac_set_ctx_params_st drbg_set_ctx_params_st
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef drbg_hmac_set_ctx_params_list
 static const OSSL_PARAM drbg_hmac_set_ctx_params_list[] = {
@@ -1084,6 +1090,7 @@ static int drbg_hmac_set_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int drbg_hmac_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 {
@@ -1106,32 +1113,32 @@ static int drbg_hmac_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *drbg_hmac_settable_ctx_params(ossl_unused void *vctx,
-                                                       ossl_unused void *p_ctx)
+    ossl_unused void *p_ctx)
 {
     return drbg_hmac_set_ctx_params_list;
 }
 
 const OSSL_DISPATCH ossl_drbg_ossl_hmac_functions[] = {
-    { OSSL_FUNC_RAND_NEWCTX, (void(*)(void))drbg_hmac_new_wrapper },
-    { OSSL_FUNC_RAND_FREECTX, (void(*)(void))drbg_hmac_free },
+    { OSSL_FUNC_RAND_NEWCTX, (void (*)(void))drbg_hmac_new_wrapper },
+    { OSSL_FUNC_RAND_FREECTX, (void (*)(void))drbg_hmac_free },
     { OSSL_FUNC_RAND_INSTANTIATE,
-      (void(*)(void))drbg_hmac_instantiate_wrapper },
+        (void (*)(void))drbg_hmac_instantiate_wrapper },
     { OSSL_FUNC_RAND_UNINSTANTIATE,
-      (void(*)(void))drbg_hmac_uninstantiate_wrapper },
-    { OSSL_FUNC_RAND_GENERATE, (void(*)(void))drbg_hmac_generate_wrapper },
-    { OSSL_FUNC_RAND_RESEED, (void(*)(void))drbg_hmac_reseed_wrapper },
-    { OSSL_FUNC_RAND_ENABLE_LOCKING, (void(*)(void))ossl_drbg_enable_locking },
-    { OSSL_FUNC_RAND_LOCK, (void(*)(void))ossl_drbg_lock },
-    { OSSL_FUNC_RAND_UNLOCK, (void(*)(void))ossl_drbg_unlock },
+        (void (*)(void))drbg_hmac_uninstantiate_wrapper },
+    { OSSL_FUNC_RAND_GENERATE, (void (*)(void))drbg_hmac_generate_wrapper },
+    { OSSL_FUNC_RAND_RESEED, (void (*)(void))drbg_hmac_reseed_wrapper },
+    { OSSL_FUNC_RAND_ENABLE_LOCKING, (void (*)(void))ossl_drbg_enable_locking },
+    { OSSL_FUNC_RAND_LOCK, (void (*)(void))ossl_drbg_lock },
+    { OSSL_FUNC_RAND_UNLOCK, (void (*)(void))ossl_drbg_unlock },
     { OSSL_FUNC_RAND_SETTABLE_CTX_PARAMS,
-      (void(*)(void))drbg_hmac_settable_ctx_params },
-    { OSSL_FUNC_RAND_SET_CTX_PARAMS, (void(*)(void))drbg_hmac_set_ctx_params },
+        (void (*)(void))drbg_hmac_settable_ctx_params },
+    { OSSL_FUNC_RAND_SET_CTX_PARAMS, (void (*)(void))drbg_hmac_set_ctx_params },
     { OSSL_FUNC_RAND_GETTABLE_CTX_PARAMS,
-      (void(*)(void))drbg_hmac_gettable_ctx_params },
-    { OSSL_FUNC_RAND_GET_CTX_PARAMS, (void(*)(void))drbg_hmac_get_ctx_params },
+        (void (*)(void))drbg_hmac_gettable_ctx_params },
+    { OSSL_FUNC_RAND_GET_CTX_PARAMS, (void (*)(void))drbg_hmac_get_ctx_params },
     { OSSL_FUNC_RAND_VERIFY_ZEROIZATION,
-      (void(*)(void))drbg_hmac_verify_zeroization },
-    { OSSL_FUNC_RAND_GET_SEED, (void(*)(void))ossl_drbg_get_seed },
-    { OSSL_FUNC_RAND_CLEAR_SEED, (void(*)(void))ossl_drbg_clear_seed },
+        (void (*)(void))drbg_hmac_verify_zeroization },
+    { OSSL_FUNC_RAND_GET_SEED, (void (*)(void))ossl_drbg_get_seed },
+    { OSSL_FUNC_RAND_CLEAR_SEED, (void (*)(void))ossl_drbg_clear_seed },
     OSSL_DISPATCH_END
 };
